####################################
# GDP Growth
####################################

rm(list=ls())                                    # clear the workspace
library(haven)                                   # a package to open Stata datasets

dat <- read_dta(file="qog_bas_cs_jan15.dta")     # open the Quality of Government Dataset

View(dat)

dem.table <- table(dat$chga_demo)
prop.table(dem.table)

growth<-as.factor(ifelse(dat$wdi_gdpgr<0, "recession", "growth"))         # classify states as being in recession or not
growth.tab<-table(growth)                                             # make a table
prop.table(growth.tab)                                                # show the proportions in each category

regime.type <- factor(dat$chga_demo, labels = c("non-democracy", "democracy"))
growtab<-table(growth, regime.type)
prop.table(growtab, margin=2)

mean(dat$wdi_gdpgr, na.rm=T)        # calculate the mean GDP growth rate around the world
sd(dat$wdi_gdpgr, na.rm=T)          # calculate the standard deviation of GDP growth around the world
var(dat$wdi_gdpgr, na.rm=T)         # calculate the variance of GDP growth around the world
sqrt(var(dat$wdi_gdpgr, na.rm=T))   # sd = sqrt(variance)

mean(dat$wdi_gdpgr[dat$chga_demo==1], na.rm=T)
mean(dat$wdi_gdpgr[dat$chga_demo==0], na.rm=T)

mu <- mean(dat$wdi_gdpgr, na.rm=T)   # store the mean
sd <- sd(dat$wdi_gdpgr, na.rm=T)     # store the standard deviation

hist(dat$wdi_gdpgr)                                # draw a histogram of GDP growth rates
hist(dat$wdi_gdpgr, breaks=10)                     # increase number of bars
hist(dat$wdi_gdpgr[dat$chga_demo==1])              # democracies only

# assume a normal distribution, summarize distribution
int.hi <- mu + 2*sd
int.lo <- mu - 2*sd
c(int.lo, int.hi)
quantile(dat$wdi_gdpgr, probs=c(0.025, 0.5, 0.975), na.rm=T)


# calculate medians and other percentiles
quantile(dat$wdi_gdpgr, probs=c(0.25, 0.5, 0.75), na.rm=T)

##########################################################
# Question: do Democracies or Dictatorships Grow Faster?
##########################################################

par(mfcol=c(2,1))
hist(dat$wdi_gdpgr[dat$chga_demo==0], breaks=10, main="Dictatorships", xlab="GDP Growth Rate",
     xlim = c(-10, 20))
hist(dat$wdi_gdpgr[dat$chga_demo==1], breaks=10, main="Democracies", xlab="GDP Growth Rate",
     xlim = c(-10, 20))

quantile(dat$wdi_gdpgr[dat$chga_demo==0], probs=c(0.25, 0.5, 0.75), na.rm=T)
quantile(dat$wdi_gdpgr[dat$chga_demo==1], probs=c(0.25, 0.5, 0.75), na.rm=T)

# plot the min, 25th, 50th, 75th, and max values of GDP growth
par(mfcol=c(1,1))
boxplot(dat$wdi_gdpgr)                                                    # for all countries in the data set
boxplot(dat$wdi_gdpgr ~ dat$chga_demo)                                        # for democracies vs. non-democracies

mean(dat$wdi_gdpgr[dat$chga_demo=="0. Dictatorship"], na.rm=T)        # calculate the mean GDP growth rate around the world
mean(dat$wdi_gdpgr[dat$chga_demo=="1. Democracy"], na.rm=T)           # calculate the mean GDP growth rate around the world

##########################################################
# Question: do Economically "Free" Countries Grow Faster?
##########################################################

plot(dat$wdi_gdpgr ~ dat$hf_efiscore)

free <- ifelse( dat$hf_efiscore > 60, 1, 0)
plot(free ~ dat$hf_efiscore)

free <- factor(free, labels=c("Not Free", "Free"))


boxplot(dat$wdi_gdpgr ~ free)

par(mfcol=c(2,1))
hist(dat$wdi_gdpgr[free=="Not Free"], breaks=10, main="Not Free", xlab="GDP Growth Rate", xlim=c(-10, 20))
hist(dat$wdi_gdpgr[free=="Free"], breaks=10, main="Free", xlab="GDP Growth Rate", xlim=c(-10, 20))



my.table <- table(free, dat$chga_demo)
prop.table(dat$my.table, margin=2)


###############################################
# Studying Variance: Congressional Ideology
###############################################

library(haven)
ideology<-read_dta(file="HL01112D21_PRES_BSSE_9.DTA")

ideology.1<-subset(ideology, cong>=60)

par(mfcol=c(1,1))
boxplot(dwnom1~cong, xlab="Congress", ylab="1st dim. DW-NOMINATE Ideology", data=ideology.1)

ideology.sd<-c()
for(i in 1:112){
  ideology.sd[i]<-sd(subset(ideology, cong==i)$dwnom1)
}
cong.plot<-40:112
plot(ideology.sd[40:112]~cong.plot, xlab = "Congress", ylab="SD, 1st dim. DW-NOM Ideology")



################################################
# Outliers:  Simulation of income distribution
################################################

rm(list=ls())
set.seed(123456)                                       # fix random number generator (so everyone gets the same values)
fake_income <-runif(10000, min=0, max=100000)          # draw some sample values of income from the uniform distribution
fake_income[1] = 1e9                                   # set one to be huge
mean(fake_income)                                      # calculate the mean of the fake_income variable
summary(fake_income)                                   # a more comprehensive summary of fake_income
boxplot(fake_income)                                   # create a boxplot of the fake_income variable
hist(fake_income)

o<-order(fake_income)                                  # put the fake_income variable in order
outliers<-which(fake_income>99000)                    # detect outliers
fake_income[outliers]                                  # identify outliers

mean(fake_income)
mean(fake_income, trim=1)
median(fake_income)
